==> pyradigm-0.6.dev1.tar.gz: pyradigm-0.6.dev1/README.md <==
# Pyradigm: PYthon based data structure to improve Dataset's InteGrity in Machine learning workflows

[![status](http://joss.theoj.org/papers/c5c231486d699bca982ca7ebd9cf32d2/status.svg)](http://joss.theoj.org/papers/c5c231486d699bca982ca7ebd9cf32d2)
[![travis](https://travis-ci.org/raamana/pyradigm.svg?branch=master)](https://travis-ci.org/raamana/pyradigm.svg?branch=master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/cffd80f290544e2e824011bfccf35ff8)](https://www.codacy.com/app/raamana/pyradigm?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raamana/pyradigm&amp;utm_campaign=Badge_Grade)
[![PyPI version](https://badge.fury.io/py/pyradigm.svg)](https://badge.fury.io/py/pyradigm)
[![Python versions](https://img.shields.io/badge/python-2.7%2C%203.5%2C%203.6-blue.svg)]
[![codecov](https://codecov.io/gh/raamana/pyradigm/branch/master/graph/badge.svg)](https://codecov.io/gh/raamana/pyradigm)


## CSVs suck. Upgrade your life with pyradigm

The illustration below describes the full functionality of `pyradigm` in the latest version `0.6`, for which docs will be updated shortly (see below illustration for docs on previous versions):

![flyer.png](docs/flyer.png)

The value of pyradigm is even more appreciated in the management of multi-modal feature sets, which becomes more efficient and easier to manage.

![multimodalflyer.png](docs/flyer_multimodal.png)

## DOCS FOR THE DEPRECATED VERSION 

Usage/demo notebook (no setup required) :

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/raamana/pyradigm/master?filepath=docs%2Fusage.ipynb)


Documentation : http://pyradigm.readthedocs.io

Installation : http://pyradigm.readthedocs.io/docs/installation.html

Usage and examples: http://pyradigm.readthedocs.io/docs/usage.html

Note: requires Python 3 or higher. Python 2 is not supported.


[![saythanks](https://img.shields.io/badge/say-thanks-ff69b4.svg)](https://saythanks.io/to/raamana)

==> pyradigm-0.6.1.tar.gz: pyradigm-0.6.1/README.md <==
# Research data management in biomedical and machine learning applications with pyradigm 

[![status](http://joss.theoj.org/papers/c5c231486d699bca982ca7ebd9cf32d2/status.svg)](http://joss.theoj.org/papers/c5c231486d699bca982ca7ebd9cf32d2)
[![travis](https://travis-ci.org/raamana/pyradigm.svg?branch=master)](https://travis-ci.org/raamana/pyradigm.svg?branch=master)
[![Codacy Badge](https://api.codacy.com/project/badge/Grade/cffd80f290544e2e824011bfccf35ff8)](https://www.codacy.com/app/raamana/pyradigm?utm_source=github.com&amp;utm_medium=referral&amp;utm_content=raamana/pyradigm&amp;utm_campaign=Badge_Grade)
[![PyPI version](https://badge.fury.io/py/pyradigm.svg)](https://badge.fury.io/py/pyradigm)
[![Python versions](https://img.shields.io/badge/python-2.7%2C%203.5%2C%203.6-blue.svg)]
[![codecov](https://codecov.io/gh/raamana/pyradigm/branch/master/graph/badge.svg)](https://codecov.io/gh/raamana/pyradigm)


## CSVs suck. Upgrade your life with pyradigm

Documentation : http://raamana.github.io/pyradigm/

Usage/demo notebook (no setup required) :

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/raamana/pyradigm/master?filepath=docs%2Fusage.ipynb)


The illustration below describes the full functionality of `pyradigm` in the latest version `0.6`, for which docs will be updated shortly (see below illustration for docs on previous versions):

![flyer.png](docs/flyer.png)

The value of pyradigm is even more appreciated in the management of multi-modal feature sets, which becomes more efficient and easier to manage.

![multimodalflyer.png](docs/flyer_multimodal.png)

Usage/demo notebook (no setup required) :

[![Binder](https://mybinder.org/badge_logo.svg)](https://mybinder.org/v2/gh/raamana/pyradigm/master?filepath=docs%2Fusage.ipynb)


Documentation : http://raamana.github.io/pyradigm/

**Name** : `pyradigm` roughly stands for PYthon based data structure to improve Dataset's InteGrity in Machine learning workflows.

[![saythanks](https://img.shields.io/badge/say-thanks-ff69b4.svg)](https://saythanks.io/to/raamana)
